psychopy_ext.models.GaborJet.__init__ — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.models.GaborJet.__init__

`GaborJet.` `__init__`(nScale=5, nOrientation=8)

  Python implementation of the Gabor-Jet model from Biederman lab.

  A given image is transformed with a Gabor wavelet and certain values on a grid are chosen for the output. Further details are in Xu et al., 2009.

  Original implementation copyright 2004 ‘Xiaomin Yue <http://geon.usc.edu/GWTgrid_simple.m>`_.

  Kwargs: | nScale (int, default: 5) Spatial frequency scales nOrientation (int, default: 8) Orientation spacing; angle = np.pi/nOrientations